pub struct ClientWrapper { /* private fields */ }Expand description
A wrapper around Client. Helps reduce external imports.
Methods from Deref<Target = Client<DynConnector, Identity>>
Sourcepub fn cancel_game_link(&self) -> CancelGameLink<C, M, R>
pub fn cancel_game_link(&self) -> CancelGameLink<C, M, R>
Constructs a fluent builder for the CancelGameLink operation.
- The fluent builder is configurable:
identity_link_token(impl Into<String>)/set_identity_link_token(Option<String>): A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
- On success, responds with
CancelGameLinkOutput - On failure, responds with
SdkError<CancelGameLinkError>
Sourcepub fn complete_game_link(&self) -> CompleteGameLink<C, M, R>
pub fn complete_game_link(&self) -> CompleteGameLink<C, M, R>
Constructs a fluent builder for the CompleteGameLink operation.
- The fluent builder is configurable:
identity_link_token(impl Into<String>)/set_identity_link_token(Option<String>): A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
- On success, responds with
CompleteGameLinkOutput - On failure, responds with
SdkError<CompleteGameLinkError>
Sourcepub fn complete_identity_avatar_upload(
&self,
) -> CompleteIdentityAvatarUpload<C, M, R>
pub fn complete_identity_avatar_upload( &self, ) -> CompleteIdentityAvatarUpload<C, M, R>
Constructs a fluent builder for the CompleteIdentityAvatarUpload operation.
- The fluent builder is configurable:
upload_id(impl Into<String>)/set_upload_id(Option<String>): A universally unique identifier.
- On success, responds with
CompleteIdentityAvatarUploadOutput - On failure, responds with
SdkError<CompleteIdentityAvatarUploadError>
Sourcepub fn follow_identity(&self) -> FollowIdentity<C, M, R>
pub fn follow_identity(&self) -> FollowIdentity<C, M, R>
Constructs a fluent builder for the FollowIdentity operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.
- On success, responds with
FollowIdentityOutput - On failure, responds with
SdkError<FollowIdentityError>
Sourcepub fn get_game_link(&self) -> GetGameLink<C, M, R>
pub fn get_game_link(&self) -> GetGameLink<C, M, R>
Constructs a fluent builder for the GetGameLink operation.
- The fluent builder is configurable:
identity_link_token(impl Into<String>)/set_identity_link_token(Option<String>):identity_link_tokenreturned byPrepareGameLink.watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.
- On success, responds with
GetGameLinkOutputwith field(s):status(Option<GameLinkStatus>): The link status between an identity and a game user.game(Option<GameHandle>): A game handle.current_identity(Option<IdentityHandle>): The current game user identity which created this game link.new_identity(Option<GetGameLinkNewIdentity>): IfstatusisGameLinkStatus$COMPLETE, this will return the new identity and identity token to use for all future requests.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetGameLinkError>
Sourcepub fn get_identity_handles(&self) -> GetIdentityHandles<C, M, R>
pub fn get_identity_handles(&self) -> GetIdentityHandles<C, M, R>
Constructs a fluent builder for the GetIdentityHandles operation.
- The fluent builder is configurable:
identity_ids(Vec<String>)/set_identity_ids(Option<Vec<String>>): A list of identity IDs.
- On success, responds with
GetIdentityHandlesOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.
- On failure, responds with
SdkError<GetIdentityHandlesError>
Sourcepub fn get_identity_profile(&self) -> GetIdentityProfile<C, M, R>
pub fn get_identity_profile(&self) -> GetIdentityProfile<C, M, R>
Constructs a fluent builder for the GetIdentityProfile operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.
- On success, responds with
GetIdentityProfileOutputwith field(s):identity(Option<IdentityProfile>): An identity profile.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetIdentityProfileError>
Sourcepub fn get_identity_self_profile(&self) -> GetIdentitySelfProfile<C, M, R>
pub fn get_identity_self_profile(&self) -> GetIdentitySelfProfile<C, M, R>
Constructs a fluent builder for the GetIdentitySelfProfile operation.
- The fluent builder is configurable:
watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.
- On success, responds with
GetIdentitySelfProfileOutputwith field(s):identity(Option<IdentityProfile>): An identity profile.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetIdentitySelfProfileError>
Sourcepub fn get_identity_summaries(&self) -> GetIdentitySummaries<C, M, R>
pub fn get_identity_summaries(&self) -> GetIdentitySummaries<C, M, R>
Constructs a fluent builder for the GetIdentitySummaries operation.
- The fluent builder is configurable:
identity_ids(Vec<String>)/set_identity_ids(Option<Vec<String>>): A list of identity IDs.
- On success, responds with
GetIdentitySummariesOutputwith field(s):identities(Option<Vec<IdentitySummary>>): A list of identity summaries.
- On failure, responds with
SdkError<GetIdentitySummariesError>
Sourcepub fn list_activities(&self) -> ListActivities<C, M, R>
pub fn list_activities(&self) -> ListActivities<C, M, R>
Constructs a fluent builder for the ListActivities operation.
- The fluent builder is configurable:
watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.
- On success, responds with
ListActivitiesOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.games(Option<Vec<GameHandle>>): A list of game handles.parties(Option<Vec<PartySummary>>): A list of party summaries.suggested_groups(Option<Vec<GroupSummary>>): A list of group summaries.suggested_players(Option<Vec<IdentityHandle>>): A list of identity handles.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<ListActivitiesError>
Sourcepub fn list_followers(&self) -> ListFollowers<C, M, R>
pub fn list_followers(&self) -> ListFollowers<C, M, R>
Constructs a fluent builder for the ListFollowers operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.anchor(impl Into<String>)/set_anchor(Option<String>): (undocumented)limit(i32)/set_limit(Option<i32>): Unsigned 32 bit integer.
- On success, responds with
ListFollowersOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.anchor(Option<String>): (undocumented)
- On failure, responds with
SdkError<ListFollowersError>
Sourcepub fn list_following(&self) -> ListFollowing<C, M, R>
pub fn list_following(&self) -> ListFollowing<C, M, R>
Constructs a fluent builder for the ListFollowing operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.anchor(impl Into<String>)/set_anchor(Option<String>): (undocumented)limit(i32)/set_limit(Option<i32>): Unsigned 32 bit integer.
- On success, responds with
ListFollowingOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.anchor(Option<String>): (undocumented)
- On failure, responds with
SdkError<ListFollowingError>
Sourcepub fn list_friends(&self) -> ListFriends<C, M, R>
pub fn list_friends(&self) -> ListFriends<C, M, R>
Constructs a fluent builder for the ListFriends operation.
- The fluent builder is configurable:
anchor(impl Into<String>)/set_anchor(Option<String>): (undocumented)limit(i32)/set_limit(Option<i32>): Unsigned 32 bit integer.
- On success, responds with
ListFriendsOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.anchor(Option<String>): (undocumented)
- On failure, responds with
SdkError<ListFriendsError>
Sourcepub fn list_mutual_friends(&self) -> ListMutualFriends<C, M, R>
pub fn list_mutual_friends(&self) -> ListMutualFriends<C, M, R>
Constructs a fluent builder for the ListMutualFriends operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.anchor(impl Into<String>)/set_anchor(Option<String>): (undocumented)limit(i32)/set_limit(Option<i32>): Unsigned 32 bit integer.
- On success, responds with
ListMutualFriendsOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.anchor(Option<String>): (undocumented)
- On failure, responds with
SdkError<ListMutualFriendsError>
Sourcepub fn prepare_game_link(&self) -> PrepareGameLink<C, M, R>
pub fn prepare_game_link(&self) -> PrepareGameLink<C, M, R>
Constructs a fluent builder for the PrepareGameLink operation.
- The fluent builder takes no input, just
sendit. - On success, responds with
PrepareGameLinkOutputwith field(s):identity_link_token(Option<String>): Pass this torivet.api.identity#GetGameLinkto get the linking status. Valid for 15 minutes.identity_link_url(Option<String>): The URL that the user should visit to link their Rivet account.expire_ts(Option<DateTime>): Timestamp (in milliseconds) at which the link will expire.
- On failure, responds with
SdkError<PrepareGameLinkError>
Sourcepub fn prepare_identity_avatar_upload(
&self,
) -> PrepareIdentityAvatarUpload<C, M, R>
pub fn prepare_identity_avatar_upload( &self, ) -> PrepareIdentityAvatarUpload<C, M, R>
Constructs a fluent builder for the PrepareIdentityAvatarUpload operation.
- The fluent builder is configurable:
path(impl Into<String>)/set_path(Option<String>): The path/filename of the identity avatar.mime(impl Into<String>)/set_mime(Option<String>): The MIME type of the identity avatar.content_length(i64)/set_content_length(Option<i64>): Unsigned 64 bit integer.
- On success, responds with
PrepareIdentityAvatarUploadOutputwith field(s):upload_id(Option<String>): A universally unique identifier.presigned_request(Option<UploadPresignedRequest>): A presigned request used to upload files. Upload your file to the given URL via a PUT request.
- On failure, responds with
SdkError<PrepareIdentityAvatarUploadError>
Sourcepub fn remove_identity_game_activity(
&self,
) -> RemoveIdentityGameActivity<C, M, R>
pub fn remove_identity_game_activity( &self, ) -> RemoveIdentityGameActivity<C, M, R>
Constructs a fluent builder for the RemoveIdentityGameActivity operation.
- The fluent builder takes no input, just
sendit. - On success, responds with
RemoveIdentityGameActivityOutput - On failure, responds with
SdkError<RemoveIdentityGameActivityError>
Sourcepub fn report_identity(&self) -> ReportIdentity<C, M, R>
pub fn report_identity(&self) -> ReportIdentity<C, M, R>
Constructs a fluent builder for the ReportIdentity operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.reason(impl Into<String>)/set_reason(Option<String>): (undocumented)
- On success, responds with
ReportIdentityOutput - On failure, responds with
SdkError<ReportIdentityError>
Sourcepub fn search_identities(&self) -> SearchIdentities<C, M, R>
pub fn search_identities(&self) -> SearchIdentities<C, M, R>
Constructs a fluent builder for the SearchIdentities operation.
- The fluent builder is configurable:
query(impl Into<String>)/set_query(Option<String>): The query to match identity display names and account numbers against.anchor(impl Into<String>)/set_anchor(Option<String>): How many identities to offset the search by.limit(i32)/set_limit(Option<i32>): Amount of identities to return.
- On success, responds with
SearchIdentitiesOutputwith field(s):identities(Option<Vec<IdentityHandle>>): A list of identity handles.anchor(Option<String>): The pagination anchor.
- On failure, responds with
SdkError<SearchIdentitiesError>
Sourcepub fn set_identity_game_activity(&self) -> SetIdentityGameActivity<C, M, R>
pub fn set_identity_game_activity(&self) -> SetIdentityGameActivity<C, M, R>
Constructs a fluent builder for the SetIdentityGameActivity operation.
- The fluent builder is configurable:
game_activity(UpdateIdentityGameActivity)/set_game_activity(Option<UpdateIdentityGameActivity>): Information about the identity’s current game. This is information that all other identities can see about what the current identity is doing.
- On success, responds with
SetIdentityGameActivityOutput - On failure, responds with
SdkError<SetIdentityGameActivityError>
Sourcepub fn setup_identity(&self) -> SetupIdentity<C, M, R>
pub fn setup_identity(&self) -> SetupIdentity<C, M, R>
Constructs a fluent builder for the SetupIdentity operation.
- The fluent builder is configurable:
existing_identity_token(impl Into<String>)/set_existing_identity_token(Option<String>): Token returned from previous call torivet.api.identity#SetupIdentity. If this token is invalid, a new identity will be returned.
- On success, responds with
SetupIdentityOutputwith field(s):identity_token(Option<String>): Token used to authenticate the identity. Should be stored somewhere permanent. Pass this torivet.api.identity#SetupIdentity$existing_identity_tokennext timerivet.api.identity#SetupIdentityis called. Token has a 90 day TTL. This means that ifrivet.api.identity#SetupIdentityis not called again within 90 days, the token will no longer be valid. If this happens, the user can recover their account through the linking process (seerivet.api.identity#PrepareGameLink). This token should be stored locally and never sent to a server or another device. If this token is comprimised, anyone with access to this token has control of the identity.identity_token_expire_ts(Option<DateTime>): Timestamp (in milliseconds) at which the token expires.identity(Option<IdentityProfile>): Information about the identity that was just authenticated.game_id(Option<String>): A universally unique identifier.
- On failure, responds with
SdkError<SetupIdentityError>
Sourcepub fn signup_for_beta(&self) -> SignupForBeta<C, M, R>
pub fn signup_for_beta(&self) -> SignupForBeta<C, M, R>
Constructs a fluent builder for the SignupForBeta operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>): (undocumented)company_name(impl Into<String>)/set_company_name(Option<String>): (undocumented)company_size(impl Into<String>)/set_company_size(Option<String>): (undocumented)preferred_tools(impl Into<String>)/set_preferred_tools(Option<String>): (undocumented)goals(impl Into<String>)/set_goals(Option<String>): (undocumented)
- On success, responds with
SignupForBetaOutput - On failure, responds with
SdkError<SignupForBetaError>
Sourcepub fn unfollow_identity(&self) -> UnfollowIdentity<C, M, R>
pub fn unfollow_identity(&self) -> UnfollowIdentity<C, M, R>
Constructs a fluent builder for the UnfollowIdentity operation.
- The fluent builder is configurable:
identity_id(impl Into<String>)/set_identity_id(Option<String>): A universally unique identifier.
- On success, responds with
UnfollowIdentityOutput - On failure, responds with
SdkError<UnfollowIdentityError>
Sourcepub fn update_identity_profile(&self) -> UpdateIdentityProfile<C, M, R>
pub fn update_identity_profile(&self) -> UpdateIdentityProfile<C, M, R>
Constructs a fluent builder for the UpdateIdentityProfile operation.
- The fluent builder is configurable:
display_name(impl Into<String>)/set_display_name(Option<String>): Represent a resource’s readable display name.account_number(i32)/set_account_number(Option<i32>): Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.bio(impl Into<String>)/set_bio(Option<String>): Detailed information about a profile.
- On success, responds with
UpdateIdentityProfileOutput - On failure, responds with
SdkError<UpdateIdentityProfileError>
Sourcepub fn update_identity_status(&self) -> UpdateIdentityStatus<C, M, R>
pub fn update_identity_status(&self) -> UpdateIdentityStatus<C, M, R>
Constructs a fluent builder for the UpdateIdentityStatus operation.
- The fluent builder is configurable:
status(IdentityStatus)/set_status(Option<IdentityStatus>): The current status of an identity. This helps players understand if another player is currently playing or has their game in the background.
- On success, responds with
UpdateIdentityStatusOutput - On failure, responds with
SdkError<UpdateIdentityStatusError>
Sourcepub fn validate_identity_profile(&self) -> ValidateIdentityProfile<C, M, R>
pub fn validate_identity_profile(&self) -> ValidateIdentityProfile<C, M, R>
Constructs a fluent builder for the ValidateIdentityProfile operation.
- The fluent builder is configurable:
display_name(impl Into<String>)/set_display_name(Option<String>): Represent a resource’s readable display name.account_number(i32)/set_account_number(Option<i32>): Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.bio(impl Into<String>)/set_bio(Option<String>): Detailed information about a profile.
- On success, responds with
ValidateIdentityProfileOutputwith field(s):errors(Option<Vec<ValidationError>>): A list of validation errors.
- On failure, responds with
SdkError<ValidateIdentityProfileError>
Sourcepub fn watch_events(&self) -> WatchEvents<C, M, R>
pub fn watch_events(&self) -> WatchEvents<C, M, R>
Constructs a fluent builder for the WatchEvents operation.
- The fluent builder is configurable:
watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.
- On success, responds with
WatchEventsOutputwith field(s):events(Option<Vec<GlobalEvent>>): A list of global events. Ordered old to new.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<WatchEventsError>