#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for SetupIdentityInput
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn existing_identity_token(self, input: impl Into<String>) -> Self
pub fn existing_identity_token(self, input: impl Into<String>) -> Self
Token returned from previous call to rivet.api.identity#SetupIdentity. If this token is invalid, a new identity will be returned.
Sourcepub fn set_existing_identity_token(self, input: Option<String>) -> Self
pub fn set_existing_identity_token(self, input: Option<String>) -> Self
Token returned from previous call to rivet.api.identity#SetupIdentity. If this token is invalid, a new identity will be returned.
Sourcepub fn build(self) -> Result<SetupIdentityInput, BuildError>
pub fn build(self) -> Result<SetupIdentityInput, BuildError>
Consumes the builder and constructs a SetupIdentityInput