#[non_exhaustive]pub struct CancelGameLinkInput {
pub identity_link_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity_link_token: Option<String>A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
Implementations
Sourceimpl CancelGameLinkInput
impl CancelGameLinkInput
Sourcepub async fn make_operation(
&self,
_config: &Config,
) -> Result<Operation<CancelGameLink, ()>, BuildError>
pub async fn make_operation( &self, _config: &Config, ) -> Result<Operation<CancelGameLink, ()>, BuildError>
Consumes the builder and constructs an Operation<CancelGameLink>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CancelGameLinkInput
Sourceimpl CancelGameLinkInput
impl CancelGameLinkInput
Sourcepub fn identity_link_token(&self) -> Option<&str>
pub fn identity_link_token(&self) -> Option<&str>
A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.