#[non_exhaustive]pub struct SetIdentityGameActivityInput {
pub game_activity: Option<UpdateIdentityGameActivity>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.game_activity: Option<UpdateIdentityGameActivity>Information about the identity’s current game. This is information that all other identities can see about what the current identity is doing.
Implementations
Sourceimpl SetIdentityGameActivityInput
impl SetIdentityGameActivityInput
Sourcepub async fn make_operation(
&self,
_config: &Config,
) -> Result<Operation<SetIdentityGameActivity, ()>, BuildError>
pub async fn make_operation( &self, _config: &Config, ) -> Result<Operation<SetIdentityGameActivity, ()>, BuildError>
Consumes the builder and constructs an Operation<SetIdentityGameActivity>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture SetIdentityGameActivityInput
Sourceimpl SetIdentityGameActivityInput
impl SetIdentityGameActivityInput
Sourcepub fn game_activity(&self) -> Option<&UpdateIdentityGameActivity>
pub fn game_activity(&self) -> Option<&UpdateIdentityGameActivity>
Information about the identity’s current game. This is information that all other identities can see about what the current identity is doing.