#[non_exhaustive]pub struct SetupIdentityInput {
pub existing_identity_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.existing_identity_token: Option<String>Token returned from previous call to rivet.api.identity#SetupIdentity. If this token is invalid, a new identity will be returned.
Implementations
Sourceimpl SetupIdentityInput
impl SetupIdentityInput
Sourcepub async fn make_operation(
&self,
_config: &Config,
) -> Result<Operation<SetupIdentity, ()>, BuildError>
pub async fn make_operation( &self, _config: &Config, ) -> Result<Operation<SetupIdentity, ()>, BuildError>
Consumes the builder and constructs an Operation<SetupIdentity>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture SetupIdentityInput
Sourceimpl SetupIdentityInput
impl SetupIdentityInput
Sourcepub fn existing_identity_token(&self) -> Option<&str>
pub fn existing_identity_token(&self) -> Option<&str>
Token returned from previous call to rivet.api.identity#SetupIdentity. If this token is invalid, a new identity will be returned.