#[non_exhaustive]pub struct UpdateIdentityStatusInput {
pub status: Option<IdentityStatus>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<IdentityStatus>The current status of an identity. This helps players understand if another player is currently playing or has their game in the background.
Implementations
Sourceimpl UpdateIdentityStatusInput
impl UpdateIdentityStatusInput
Sourcepub async fn make_operation(
&self,
_config: &Config,
) -> Result<Operation<UpdateIdentityStatus, ()>, BuildError>
pub async fn make_operation( &self, _config: &Config, ) -> Result<Operation<UpdateIdentityStatus, ()>, BuildError>
Consumes the builder and constructs an Operation<UpdateIdentityStatus>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateIdentityStatusInput
Sourceimpl UpdateIdentityStatusInput
impl UpdateIdentityStatusInput
Sourcepub fn status(&self) -> Option<&IdentityStatus>
pub fn status(&self) -> Option<&IdentityStatus>
The current status of an identity. This helps players understand if another player is currently playing or has their game in the background.