#[non_exhaustive]pub struct ValidateIdentityProfileInput {
pub display_name: Option<String>,
pub account_number: Option<i32>,
pub bio: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: Option<String>Represent a resource’s readable display name.
account_number: Option<i32>Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.
bio: Option<String>Detailed information about a profile.
Implementations
Sourceimpl ValidateIdentityProfileInput
impl ValidateIdentityProfileInput
Sourcepub async fn make_operation(
&self,
_config: &Config,
) -> Result<Operation<ValidateIdentityProfile, ()>, BuildError>
pub async fn make_operation( &self, _config: &Config, ) -> Result<Operation<ValidateIdentityProfile, ()>, BuildError>
Consumes the builder and constructs an Operation<ValidateIdentityProfile>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ValidateIdentityProfileInput
Sourceimpl ValidateIdentityProfileInput
impl ValidateIdentityProfileInput
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
Represent a resource’s readable display name.
Sourcepub fn account_number(&self) -> Option<i32>
pub fn account_number(&self) -> Option<i32>
Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.