#[non_exhaustive]pub enum ChatTopic {
Direct(ChatTopicDirect),
Group(ChatTopicGroup),
Party(ChatTopicParty),
#[non_exhaustive] Unknown,
}Expand description
Represents the topic of the given chat thread.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Direct(ChatTopicDirect)
rivet.chat#ChatTopic variant for direct (identity to identity) chats.
Group(ChatTopicGroup)
rivet.chat#ChatTopic variant for groups.
Party(ChatTopicParty)
rivet.chat#ChatTopic variant for parties.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl ChatTopic
impl ChatTopic
Sourcepub fn as_direct(&self) -> Result<&ChatTopicDirect, &Self>
pub fn as_direct(&self) -> Result<&ChatTopicDirect, &Self>
Tries to convert the enum instance into Direct, extracting the inner ChatTopicDirect.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_group(&self) -> Result<&ChatTopicGroup, &Self>
pub fn as_group(&self) -> Result<&ChatTopicGroup, &Self>
Tries to convert the enum instance into Group, extracting the inner ChatTopicGroup.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_party(&self) -> Result<&ChatTopicParty, &Self>
pub fn as_party(&self) -> Result<&ChatTopicParty, &Self>
Tries to convert the enum instance into Party, extracting the inner ChatTopicParty.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.