#[non_exhaustive]pub enum GameLinkStatus {
Cancelled,
Complete,
Incomplete,
Unknown(String),
}Expand description
The link status between an identity and a game user.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cancelled
Complete
Incomplete
Unknown(String)
Unknown contains new variants that have been added since this code was generated.
Implementations