#[non_exhaustive]pub enum GameStatAggregationMethod {
Average,
Max,
Min,
Sum,
Unknown(String),
}Expand description
A value denoting the aggregation method of a game statistic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Average
Average aggergation.
Max
Maximum value aggregation.
Min
Minimum value aggregation.
Sum
Summation aggregation.
Unknown(String)
Unknown contains new variants that have been added since this code was generated.
Implementations