#[non_exhaustive]pub enum GameStatFormatMethod {
DurationHundredthSecond,
DurationMinute,
DuractionSecond,
Float1,
Float2,
Float3,
Integer,
Unknown(String),
}Expand description
A value denoting the format method of a game statistic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DurationHundredthSecond
A duration with hundredth-second precision (1d 2h 45m 21.46s).
DurationMinute
A duration with minute precision (1d 2h 45m).
DuractionSecond
A duration with second precision (1d 2h 45m 21s).
Float1
A float with 1 decimal (1,234.5).
Float2
A float with 2 decimals (1,234.56).
Float3
A float with 3 decimals (1,234.567).
Integer
An integer with no decimals (1,234).
Unknown(String)
Unknown contains new variants that have been added since this code was generated.
Implementations