#[non_exhaustive]pub enum GameStatSortingMethod {
Asc,
Desc,
Unknown(String),
}Expand description
A value denoting the sorting method of a game statistic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Asc
Ascending sorting.
Desc
Descending sorting.
Unknown(String)
Unknown contains new variants that have been added since this code was generated.
Implementations