#[non_exhaustive]pub struct GameStatConfig {
pub record_id: Option<String>,
pub icon_id: Option<String>,
pub format: Option<GameStatFormatMethod>,
pub aggregation: Option<GameStatAggregationMethod>,
pub sorting: Option<GameStatSortingMethod>,
pub priority: Option<i32>,
pub display_name: Option<String>,
pub postfix_singular: Option<String>,
pub postfix_plural: Option<String>,
pub prefix_singular: Option<String>,
pub prefix_plural: Option<String>,
}Expand description
A game statistic config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.record_id: Option<String>A universally unique identifier.
icon_id: Option<String>A universally unique identifier.
format: Option<GameStatFormatMethod>A value denoting the format method of a game statistic.
aggregation: Option<GameStatAggregationMethod>A value denoting the aggregation method of a game statistic.
sorting: Option<GameStatSortingMethod>A value denoting the sorting method of a game statistic.
priority: Option<i32>Unsigned 32 bit integer.
display_name: Option<String>Represent a resource’s readable display name.
postfix_singular: Option<String>A string appended to the end of a singular game statistic’s value. Example: 1 dollar.
postfix_plural: Option<String>A string appended to the end of a game statistic’s value that is not exactly 1. Example: 45 dollars.
prefix_singular: Option<String>A string appended to the beginning of a singular game statistic’s value. Example: value 1.
prefix_plural: Option<String>A string prepended to the beginning of a game statistic’s value that is not exactly 1. Example: values 45.
Implementations
Sourceimpl GameStatConfig
impl GameStatConfig
Sourcepub fn format(&self) -> Option<&GameStatFormatMethod>
pub fn format(&self) -> Option<&GameStatFormatMethod>
A value denoting the format method of a game statistic.
Sourcepub fn aggregation(&self) -> Option<&GameStatAggregationMethod>
pub fn aggregation(&self) -> Option<&GameStatAggregationMethod>
A value denoting the aggregation method of a game statistic.
Sourcepub fn sorting(&self) -> Option<&GameStatSortingMethod>
pub fn sorting(&self) -> Option<&GameStatSortingMethod>
A value denoting the sorting method of a game statistic.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
Represent a resource’s readable display name.
Sourcepub fn postfix_singular(&self) -> Option<&str>
pub fn postfix_singular(&self) -> Option<&str>
A string appended to the end of a singular game statistic’s value. Example: 1 dollar.
Sourcepub fn postfix_plural(&self) -> Option<&str>
pub fn postfix_plural(&self) -> Option<&str>
A string appended to the end of a game statistic’s value that is not exactly 1. Example: 45 dollars.
Sourcepub fn prefix_singular(&self) -> Option<&str>
pub fn prefix_singular(&self) -> Option<&str>
A string appended to the beginning of a singular game statistic’s value. Example: value 1.
Sourcepub fn prefix_plural(&self) -> Option<&str>
pub fn prefix_plural(&self) -> Option<&str>
A string prepended to the beginning of a game statistic’s value that is not exactly 1. Example: values 45.
Sourceimpl GameStatConfig
impl GameStatConfig
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GameStatConfig