#[non_exhaustive]pub struct GlobalEvent {
pub ts: Option<DateTime>,
pub kind: Option<GlobalEventKind>,
pub notification: Option<GlobalEventNotification>,
}Expand description
An event relevant to the current identity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ts: Option<DateTime>RFC3339 timestamp.
kind: Option<GlobalEventKind>Kind of event that occured.
notification: Option<GlobalEventNotification>Notifications represent information that should be presented to the user immediately. At the moment, only chat message events have associated notifications. # Display Notifications should be displayed in an unobtrusive manner throughout the entire game. Notifications should disappear after a few seconds if not interacted with. # Interactions If your platform supports it, notifications should be able to be clicked or tapped in order to open the relevant context for the event. For a simple implementation of notification interactions, open url in a web browser to present the relevant context. For example, a chat message notification will open the thread the chat message was sent in. For advanced implementations that implement a custom chat UI, use rivet.api.identity.common#GlobalEvent$kind to determine what action to take when the notification is interacted with. For example, if the global event kind is rivet.api.identity.common#GlobalEventChatMessage, then open the chat UI for the given thread.
Implementations
Sourceimpl GlobalEvent
impl GlobalEvent
Sourcepub fn kind(&self) -> Option<&GlobalEventKind>
pub fn kind(&self) -> Option<&GlobalEventKind>
Kind of event that occured.
Sourcepub fn notification(&self) -> Option<&GlobalEventNotification>
pub fn notification(&self) -> Option<&GlobalEventNotification>
Notifications represent information that should be presented to the user immediately. At the moment, only chat message events have associated notifications. # Display Notifications should be displayed in an unobtrusive manner throughout the entire game. Notifications should disappear after a few seconds if not interacted with. # Interactions If your platform supports it, notifications should be able to be clicked or tapped in order to open the relevant context for the event. For a simple implementation of notification interactions, open url in a web browser to present the relevant context. For example, a chat message notification will open the thread the chat message was sent in. For advanced implementations that implement a custom chat UI, use rivet.api.identity.common#GlobalEvent$kind to determine what action to take when the notification is interacted with. For example, if the global event kind is rivet.api.identity.common#GlobalEventChatMessage, then open the chat UI for the given thread.
Sourceimpl GlobalEvent
impl GlobalEvent
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GlobalEvent