#[non_exhaustive]pub struct GlobalEventChatRead {
pub thread_id: Option<String>,
pub read_ts: Option<DateTime>,
}Expand description
rivet.api.identity.common#GlobalEventKind variant for chat reads. Received any time the last read timestamp is set. Used to update the status of unread indicators on chats.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.thread_id: Option<String>A universally unique identifier.
read_ts: Option<DateTime>RFC3339 timestamp.
Implementations
Sourceimpl GlobalEventChatRead
impl GlobalEventChatRead
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GlobalEventChatRead