#[non_exhaustive]pub struct GlobalEventMatchmakerLobbyJoin {
pub lobby: Option<MatchmakerLobbyJoinInfo>,
}Expand description
rivet.api.identity.common#GlobalEventKind variant for party updates. Received when the identity should be instructed to join a lobby. This needs to be implemented in conjunction with parties in order to force clients to join the same lobby as the party they’re in.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lobby: Option<MatchmakerLobbyJoinInfo>A matchmaker lobby.
Implementations
Sourceimpl GlobalEventMatchmakerLobbyJoin
impl GlobalEventMatchmakerLobbyJoin
Sourcepub fn lobby(&self) -> Option<&MatchmakerLobbyJoinInfo>
pub fn lobby(&self) -> Option<&MatchmakerLobbyJoinInfo>
A matchmaker lobby.
Sourceimpl GlobalEventMatchmakerLobbyJoin
impl GlobalEventMatchmakerLobbyJoin
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GlobalEventMatchmakerLobbyJoin