#[non_exhaustive]pub struct GlobalEventNotification {
pub title: Option<String>,
pub description: Option<String>,
pub thumbnail_url: Option<String>,
pub url: Option<String>,
}Expand description
Notifications represent information that should be presented to the user immediately. At the moment, only chat message events have associated notifications. # Display Notifications should be displayed in an unobtrusive manner throughout the entire game. Notifications should disappear after a few seconds if not interacted with. # Interactions If your platform supports it, notifications should be able to be clicked or tapped in order to open the relevant context for the event. For a simple implementation of notification interactions, open url in a web browser to present the relevant context. For example, a chat message notification will open the thread the chat message was sent in. For advanced implementations that implement a custom chat UI, use rivet.api.identity.common#GlobalEvent$kind to determine what action to take when the notification is interacted with. For example, if the global event kind is rivet.api.identity.common#GlobalEventChatMessage, then open the chat UI for the given thread.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>description: Option<String>thumbnail_url: Option<String>URL to an image thumbnail that should be shown for this notification.
url: Option<String>Rivet Hub URL that holds the relevant context for this notification.
Implementations
Sourceimpl GlobalEventNotification
impl GlobalEventNotification
Sourceimpl GlobalEventNotification
impl GlobalEventNotification
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GlobalEventNotification