#[non_exhaustive]pub struct GlobalEventPartyUpdate {
pub party: Option<PartySummary>,
}Expand description
rivet.api.identity.common#GlobalEventKind variant for party updates. Received any time the identity joins a party, a party is updated, or when the identity leaves a party.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.party: Option<PartySummary>If null, the identity left the party.
Implementations
Sourceimpl GlobalEventPartyUpdate
impl GlobalEventPartyUpdate
Sourcepub fn party(&self) -> Option<&PartySummary>
pub fn party(&self) -> Option<&PartySummary>
If null, the identity left the party.
Sourceimpl GlobalEventPartyUpdate
impl GlobalEventPartyUpdate
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GlobalEventPartyUpdate