IdentityProfile

Struct IdentityProfile 

#[non_exhaustive]
pub struct IdentityProfile {
Show 21 fields pub identity_id: Option<String>, pub display_name: Option<String>, pub account_number: Option<i32>, pub avatar_url: Option<String>, pub presence: Option<IdentityPresence>, pub party: Option<PartySummary>, pub is_registered: Option<bool>, pub external: Option<IdentityExternalLinks>, pub is_admin: Option<bool>, pub is_game_linked: Option<bool>, pub dev_state: Option<IdentityDevState>, pub follower_count: Option<i32>, pub following_count: Option<i32>, pub following: Option<bool>, pub is_following_me: Option<bool>, pub is_mutual_following: Option<bool>, pub join_ts: Option<DateTime>, pub bio: Option<String>, pub linked_accounts: Option<Vec<IdentityLinkedAccount>>, pub groups: Option<Vec<IdentityGroup>>, pub games: Option<Vec<GameStatSummary>>,
}
An identity profile.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
identity_id: Option<String>

A universally unique identifier.

display_name: Option<String>

Represent a resource’s readable display name.

account_number: Option<i32>

Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.

avatar_url: Option<String>

The URL of this identity’s avatar image.

presence: Option<IdentityPresence>

Information about the identity’s current status, party, and active game.

party: Option<PartySummary>

A party summary.

is_registered: Option<bool>

Whether or not this identity is registered with a linked account.

external: Option<IdentityExternalLinks>

External links for an identity.

is_admin: Option<bool>

Whether or not this identity is an admin.

is_game_linked: Option<bool>

Whether or not this game user has been linked through the Rivet dashboard.

dev_state: Option<IdentityDevState>

The state of the given identity’s developer status.

follower_count: Option<i32>

Unsigned 32 bit integer.

following_count: Option<i32>

Unsigned 32 bit integer.

following: Option<bool>

Whether or not the requestee’s identity is following this identity.

is_following_me: Option<bool>

Whether or not this identity following the requestee’s identity.

is_mutual_following: Option<bool>

Whether or not this identity is both followng and is followed by the requestee’s identity.

join_ts: Option<DateTime>

RFC3339 timestamp.

bio: Option<String>

Detailed information about a profile.

linked_accounts: Option<Vec<IdentityLinkedAccount>>

A list of an identity’s linked accounts.

groups: Option<Vec<IdentityGroup>>

A list of groups that the given identity is in.

games: Option<Vec<GameStatSummary>>

A list of game statistic summaries.

Implementations

Source

impl IdentityProfile

pub fn identity_id(&self) -> Option<&str>

A universally unique identifier.

pub fn display_name(&self) -> Option<&str>

Represent a resource’s readable display name.

pub fn account_number(&self) -> Option<i32>

Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.

pub fn avatar_url(&self) -> Option<&str>

The URL of this identity’s avatar image.

pub fn presence(&self) -> Option<&IdentityPresence>

Information about the identity’s current status, party, and active game.

pub fn party(&self) -> Option<&PartySummary>

A party summary.

pub fn is_registered(&self) -> Option<bool>

Whether or not this identity is registered with a linked account.

pub fn external(&self) -> Option<&IdentityExternalLinks>

External links for an identity.

pub fn is_admin(&self) -> Option<bool>

Whether or not this identity is an admin.

pub fn is_game_linked(&self) -> Option<bool>

Whether or not this game user has been linked through the Rivet dashboard.

pub fn dev_state(&self) -> Option<&IdentityDevState>

The state of the given identity’s developer status.

pub fn follower_count(&self) -> Option<i32>

Unsigned 32 bit integer.

pub fn following_count(&self) -> Option<i32>

Unsigned 32 bit integer.

pub fn following(&self) -> Option<bool>

Whether or not the requestee’s identity is following this identity.

pub fn is_following_me(&self) -> Option<bool>

Whether or not this identity following the requestee’s identity.

pub fn is_mutual_following(&self) -> Option<bool>

Whether or not this identity is both followng and is followed by the requestee’s identity.

pub fn join_ts(&self) -> Option<&DateTime>

RFC3339 timestamp.

pub fn bio(&self) -> Option<&str>

Detailed information about a profile.

pub fn linked_accounts(&self) -> Option<&[IdentityLinkedAccount]>

A list of an identity’s linked accounts.

pub fn groups(&self) -> Option<&[IdentityGroup]>

A list of groups that the given identity is in.

pub fn games(&self) -> Option<&[GameStatSummary]>

A list of game statistic summaries.

Source

impl IdentityProfile

pub fn builder() -> Builder

Creates a new builder-style object to manufacture IdentityProfile