#[non_exhaustive]pub struct IdentitySummary {
pub identity_id: Option<String>,
pub display_name: Option<String>,
pub account_number: Option<i32>,
pub avatar_url: Option<String>,
pub presence: Option<IdentityPresence>,
pub party: Option<PartyHandle>,
pub is_registered: Option<bool>,
pub external: Option<IdentityExternalLinks>,
pub following: Option<bool>,
pub is_following_me: Option<bool>,
pub is_mutual_following: Option<bool>,
}Expand description
An identity summary.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity_id: Option<String>A universally unique identifier.
display_name: Option<String>Represent a resource’s readable display name.
account_number: Option<i32>Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.
avatar_url: Option<String>The URL of this identity’s avatar image.
presence: Option<IdentityPresence>Information about the identity’s current status, party, and active game.
party: Option<PartyHandle>A party handle.
is_registered: Option<bool>Whether or not this identity is registered with a linked account.
external: Option<IdentityExternalLinks>External links for an identity.
following: Option<bool>Whether or not the requestee’s identity is following this identity.
is_following_me: Option<bool>Whether or not this identity following the requestee’s identity.
is_mutual_following: Option<bool>Whether or not this identity is both followng and is followed by the requestee’s identity.
Implementations
Sourceimpl IdentitySummary
impl IdentitySummary
Sourcepub fn identity_id(&self) -> Option<&str>
pub fn identity_id(&self) -> Option<&str>
A universally unique identifier.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
Represent a resource’s readable display name.
Sourcepub fn account_number(&self) -> Option<i32>
pub fn account_number(&self) -> Option<i32>
Identity profile account number (#1234). These are assigned in addition to an identity’s display name in order to allow multiple identities to have the same display name while still providing a unique handle. These are unique to each display name; you can have multiple accounts with different display names and the same account number.
Sourcepub fn avatar_url(&self) -> Option<&str>
pub fn avatar_url(&self) -> Option<&str>
The URL of this identity’s avatar image.
Sourcepub fn presence(&self) -> Option<&IdentityPresence>
pub fn presence(&self) -> Option<&IdentityPresence>
Information about the identity’s current status, party, and active game.
Sourcepub fn party(&self) -> Option<&PartyHandle>
pub fn party(&self) -> Option<&PartyHandle>
A party handle.
Sourcepub fn is_registered(&self) -> Option<bool>
pub fn is_registered(&self) -> Option<bool>
Whether or not this identity is registered with a linked account.
Sourcepub fn external(&self) -> Option<&IdentityExternalLinks>
pub fn external(&self) -> Option<&IdentityExternalLinks>
External links for an identity.
Sourcepub fn following(&self) -> Option<bool>
pub fn following(&self) -> Option<bool>
Whether or not the requestee’s identity is following this identity.
Sourcepub fn is_following_me(&self) -> Option<bool>
pub fn is_following_me(&self) -> Option<bool>
Whether or not this identity following the requestee’s identity.
Sourcepub fn is_mutual_following(&self) -> Option<bool>
pub fn is_mutual_following(&self) -> Option<bool>
Whether or not this identity is both followng and is followed by the requestee’s identity.
Sourceimpl IdentitySummary
impl IdentitySummary
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture IdentitySummary