#[non_exhaustive]pub struct UpdateIdentityGameActivity {
pub message: Option<String>,
pub public_metadata: Option<Document>,
pub mutual_metadata: Option<Document>,
}Expand description
Information about the identity’s current game. This is information that all other identities can see about what the current identity is doing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>A short message about the current game activity.
public_metadata: Option<Document>JSON data seen by anyone.
mutual_metadata: Option<Document>JSON data seen only by the given identity and their mutual followers.
Implementations
Sourceimpl UpdateIdentityGameActivity
impl UpdateIdentityGameActivity
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateIdentityGameActivity