#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for ValidationError
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
Appends an item to path.
To override the contents of this collection use set_path.
A list of strings denoting the origin of a validation error.
Sourcepub fn set_path(self, input: Option<Vec<String>>) -> Self
pub fn set_path(self, input: Option<Vec<String>>) -> Self
A list of strings denoting the origin of a validation error.
Sourcepub fn build(self) -> ValidationError
pub fn build(self) -> ValidationError
Consumes the builder and constructs a ValidationError