#[non_exhaustive]pub struct SetupIdentityOutput {
pub identity_token: Option<String>,
pub identity_token_expire_ts: Option<DateTime>,
pub identity: Option<IdentityProfile>,
pub game_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity_token: Option<String>Token used to authenticate the identity. Should be stored somewhere permanent. Pass this to rivet.api.identity#SetupIdentity$existing_identity_token next time rivet.api.identity#SetupIdentity is called. Token has a 90 day TTL. This means that if rivet.api.identity#SetupIdentity is not called again within 90 days, the token will no longer be valid. If this happens, the user can recover their account through the linking process (see rivet.api.identity#PrepareGameLink). This token should be stored locally and never sent to a server or another device. If this token is comprimised, anyone with access to this token has control of the identity.
identity_token_expire_ts: Option<DateTime>Timestamp (in milliseconds) at which the token expires.
identity: Option<IdentityProfile>Information about the identity that was just authenticated.
game_id: Option<String>A universally unique identifier.
Implementations
Sourceimpl SetupIdentityOutput
impl SetupIdentityOutput
Sourcepub fn identity_token(&self) -> Option<&str>
pub fn identity_token(&self) -> Option<&str>
Token used to authenticate the identity. Should be stored somewhere permanent. Pass this to rivet.api.identity#SetupIdentity$existing_identity_token next time rivet.api.identity#SetupIdentity is called. Token has a 90 day TTL. This means that if rivet.api.identity#SetupIdentity is not called again within 90 days, the token will no longer be valid. If this happens, the user can recover their account through the linking process (see rivet.api.identity#PrepareGameLink). This token should be stored locally and never sent to a server or another device. If this token is comprimised, anyone with access to this token has control of the identity.
Sourcepub fn identity_token_expire_ts(&self) -> Option<&DateTime>
pub fn identity_token_expire_ts(&self) -> Option<&DateTime>
Timestamp (in milliseconds) at which the token expires.
Sourcepub fn identity(&self) -> Option<&IdentityProfile>
pub fn identity(&self) -> Option<&IdentityProfile>
Information about the identity that was just authenticated.
Sourceimpl SetupIdentityOutput
impl SetupIdentityOutput
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture SetupIdentityOutput