#[non_exhaustive]pub enum GlobalEventKind {
ChatMessage(GlobalEventChatMessage),
ChatRead(GlobalEventChatRead),
ChatThreadRemove(GlobalEventChatThreadRemove),
IdentityUpdate(GlobalEventIdentityUpdate),
MatchmakerLobbyJoin(GlobalEventMatchmakerLobbyJoin),
PartyUpdate(GlobalEventPartyUpdate),
#[non_exhaustive] Unknown,
}Expand description
Kind of event that occured.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ChatMessage(GlobalEventChatMessage)
rivet.api.identity.common#GlobalEventKind variant for chat messages. Received any time a message is sent to a chat the identity is in.
ChatRead(GlobalEventChatRead)
rivet.api.identity.common#GlobalEventKind variant for chat reads. Received any time the last read timestamp is set. Used to update the status of unread indicators on chats.
ChatThreadRemove(GlobalEventChatThreadRemove)
rivet.api.identity.common#GlobalEventKind variant for a chat thread being removed. Received any time the current identity is no longer able to access the given thread. This can happen if
IdentityUpdate(GlobalEventIdentityUpdate)
rivet.api.identity.common#GlobalEventKind variant for identity updates. Received any time identity details are changed OR the identity switches.
MatchmakerLobbyJoin(GlobalEventMatchmakerLobbyJoin)
rivet.api.identity.common#GlobalEventKind variant for party updates. Received when the identity should be instructed to join a lobby. This needs to be implemented in conjunction with parties in order to force clients to join the same lobby as the party they’re in.
PartyUpdate(GlobalEventPartyUpdate)
rivet.api.identity.common#GlobalEventKind variant for party updates. Received any time the identity joins a party, a party is updated, or when the identity leaves a party.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl GlobalEventKind
impl GlobalEventKind
Sourcepub fn as_chat_message(&self) -> Result<&GlobalEventChatMessage, &Self>
pub fn as_chat_message(&self) -> Result<&GlobalEventChatMessage, &Self>
Tries to convert the enum instance into ChatMessage, extracting the inner GlobalEventChatMessage.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_chat_message(&self) -> bool
pub fn is_chat_message(&self) -> bool
Returns true if this is a ChatMessage.
Sourcepub fn as_chat_read(&self) -> Result<&GlobalEventChatRead, &Self>
pub fn as_chat_read(&self) -> Result<&GlobalEventChatRead, &Self>
Tries to convert the enum instance into ChatRead, extracting the inner GlobalEventChatRead.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_chat_read(&self) -> bool
pub fn is_chat_read(&self) -> bool
Returns true if this is a ChatRead.
Sourcepub fn as_chat_thread_remove(
&self,
) -> Result<&GlobalEventChatThreadRemove, &Self>
pub fn as_chat_thread_remove( &self, ) -> Result<&GlobalEventChatThreadRemove, &Self>
Tries to convert the enum instance into ChatThreadRemove, extracting the inner GlobalEventChatThreadRemove.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_chat_thread_remove(&self) -> bool
pub fn is_chat_thread_remove(&self) -> bool
Returns true if this is a ChatThreadRemove.
Sourcepub fn as_identity_update(&self) -> Result<&GlobalEventIdentityUpdate, &Self>
pub fn as_identity_update(&self) -> Result<&GlobalEventIdentityUpdate, &Self>
Tries to convert the enum instance into IdentityUpdate, extracting the inner GlobalEventIdentityUpdate.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_identity_update(&self) -> bool
pub fn is_identity_update(&self) -> bool
Returns true if this is a IdentityUpdate.
Sourcepub fn as_matchmaker_lobby_join(
&self,
) -> Result<&GlobalEventMatchmakerLobbyJoin, &Self>
pub fn as_matchmaker_lobby_join( &self, ) -> Result<&GlobalEventMatchmakerLobbyJoin, &Self>
Tries to convert the enum instance into MatchmakerLobbyJoin, extracting the inner GlobalEventMatchmakerLobbyJoin.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_matchmaker_lobby_join(&self) -> bool
pub fn is_matchmaker_lobby_join(&self) -> bool
Returns true if this is a MatchmakerLobbyJoin.
Sourcepub fn as_party_update(&self) -> Result<&GlobalEventPartyUpdate, &Self>
pub fn as_party_update(&self) -> Result<&GlobalEventPartyUpdate, &Self>
Tries to convert the enum instance into PartyUpdate, extracting the inner GlobalEventPartyUpdate.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_party_update(&self) -> bool
pub fn is_party_update(&self) -> bool
Returns true if this is a PartyUpdate.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.