#[non_exhaustive]pub enum PartyMemberState {
Idle(PartyMemberStateIdle),
MatchmakerFindingLobby(PartyMemberStateMatchmakerFindingLobby),
MatchmakerLobby(PartyMemberStateMatchmakerLobby),
MatchmakerPending(PartyMemberStateMatchmakerPending),
#[non_exhaustive] Unknown,
}Expand description
A union representing the current state of a party member.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Idle(PartyMemberStateIdle)
A party member state denoting that the member is idle.
MatchmakerFindingLobby(PartyMemberStateMatchmakerFindingLobby)
A party member state denoting that the member is currently searching for a lobby.
MatchmakerLobby(PartyMemberStateMatchmakerLobby)
A party member state denoting that the member is in a lobby.
MatchmakerPending(PartyMemberStateMatchmakerPending)
A party member state denoting that the member is currently waiting to start matchmaking.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl PartyMemberState
impl PartyMemberState
Sourcepub fn as_idle(&self) -> Result<&PartyMemberStateIdle, &Self>
pub fn as_idle(&self) -> Result<&PartyMemberStateIdle, &Self>
Tries to convert the enum instance into Idle, extracting the inner PartyMemberStateIdle.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_matchmaker_finding_lobby(
&self,
) -> Result<&PartyMemberStateMatchmakerFindingLobby, &Self>
pub fn as_matchmaker_finding_lobby( &self, ) -> Result<&PartyMemberStateMatchmakerFindingLobby, &Self>
Tries to convert the enum instance into MatchmakerFindingLobby, extracting the inner PartyMemberStateMatchmakerFindingLobby.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_matchmaker_finding_lobby(&self) -> bool
pub fn is_matchmaker_finding_lobby(&self) -> bool
Returns true if this is a MatchmakerFindingLobby.
Sourcepub fn as_matchmaker_lobby(
&self,
) -> Result<&PartyMemberStateMatchmakerLobby, &Self>
pub fn as_matchmaker_lobby( &self, ) -> Result<&PartyMemberStateMatchmakerLobby, &Self>
Tries to convert the enum instance into MatchmakerLobby, extracting the inner PartyMemberStateMatchmakerLobby.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_matchmaker_lobby(&self) -> bool
pub fn is_matchmaker_lobby(&self) -> bool
Returns true if this is a MatchmakerLobby.
Sourcepub fn as_matchmaker_pending(
&self,
) -> Result<&PartyMemberStateMatchmakerPending, &Self>
pub fn as_matchmaker_pending( &self, ) -> Result<&PartyMemberStateMatchmakerPending, &Self>
Tries to convert the enum instance into MatchmakerPending, extracting the inner PartyMemberStateMatchmakerPending.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_matchmaker_pending(&self) -> bool
pub fn is_matchmaker_pending(&self) -> bool
Returns true if this is a MatchmakerPending.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.